﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;

using CamBam;
using CamBam.Geom;
using CamBam.CAD;
using CamBam.UI;
using CamBam.CAM;
using CamBam.Values;
using CamBam.Util;

namespace ExcellonIO
{
    /// <summary>
    /// This class handles the plugin initialisation.
    /// </summary>
    public class ExcellonIOPlugin
    {
        /// <summary>
        /// This is the plugin entry point and will be called once by CamBam during initialisation.
        /// This method should handle plugin initialisation and registering any menu handlers etc.
        /// </summary>
        /// <param name="ui">The current CamBam user interface instace.</param>
        public static void InitPlugin(CamBamUI ui)
        {
            ExcellonIOConfig.ReadConfigFile();

            // Register a new file handler
            // The file handler class defines a property containing the file filter and extension
            CamBamUI.CADFileHandlers.Add(new ExcellonIOHandler());

            // Detect when CamBam is closing
            ThisApplication.TopWindow.FormClosing += new System.Windows.Forms.FormClosingEventHandler(TopWindow_FormClosing);

            // Add a menu to the top Plugins menu to edit this plugins configuration
            ToolStripMenuItem miConfig = new ToolStripMenuItem("ExcellonIO Config");
            miConfig.Click += new EventHandler(ExcellonIOConfig_Click);
            ui.Menus.mnuPlugins.DropDownItems.Add(miConfig);

        }

        /// <summary>
        /// Excellon IO Config menu handler.
        /// Display a dialog box to edit the plugin's configuration.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        static void ExcellonIOConfig_Click(object sender, EventArgs e)
        {
            // Make sure the plugin configuration has been read...
            if (ExcellonIOConfig.Defaults == null)
                ExcellonIOConfig.ReadConfigFile();

            XPropertyGrid pg = new XPropertyGrid();
            pg.SelectedObject = ExcellonIOConfig.Defaults;
            // ControlWrapper is a simple form that contains a single control.
            ControlWrapper cw = new ControlWrapper(pg);
            cw.Text = "Excellon IO Options";
            cw.ShowDialog(ThisApplication.TopWindow);
        }

        /// <summary>
        /// CamBam TopWindow closing event handler.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        static void TopWindow_FormClosing(object sender, System.Windows.Forms.FormClosingEventArgs e)
        {
            // CamBam is closing, so save any plugin configuration settings...
            if (CamBamConfig.Defaults.SaveSettingsOnExit)
                ExcellonIOConfig.WriteConfigFile();
        }
    }
}
